Orthogonal Array Package
========================

A mex interface to the Orthogonal Array package is contained in the subdirectory `mex/`.

Installation
------------

To build the mex file one can use the script `mex/compile.m`.


